@@ -749,13 +749,13 @@ namespace
       /// \todo
       ///     Remove all subdirectories recursively
       //-----------------------------------------------------------------
-    QUEUE_LOG_MESSAGE( "Exit: " << Path
-                       << " Exception: " << exc
-                       ,
-                       MT_DEBUG,
-                       50,
-                       method_name,
-                       "CXX" );
+      QUEUE_LOG_MESSAGE( "Exit: " << Path
+                         << " Exception: " << exc
+                         ,
+                         MT_DEBUG,
+                         50,
+                         method_name,
+                         "CXX" );
       throw std::runtime_error( exc );
     }
     //-------------------------------------------------------------------
@@ -912,102 +912,114 @@ namespace
          entry_cur != entry_last;
          ++entry_cur )
     {
-      static const std::string tmp( ".tmp" );
-
-      //-----------------------------------------------------------------
-      // Within this loop, the file should be identified.
-      // Subsequent checks will only be done if the previous check
-      //   failed.
-      //-----------------------------------------------------------------
-      //-----------------------------------------------------------------
-      // \todo Check if the file should be ignored
-      //-----------------------------------------------------------------
-      if ( ( ( entry_cur->size( ) > 0 )
-             && ( (*entry_cur)[ 0 ] == '.' ) )
-           || ( ( entry_cur->size( ) >= tmp.size( ) )
-                && ( entry_cur->compare( entry_cur->size( ) -
-                                         tmp.size( ),
-                                         std::string::npos,
-                                         tmp ) == 0 ) ) )
+      try
       {
-        continue;
-      }
+        static const std::string tmp( ".tmp" );
+
+        //-----------------------------------------------------------------
+        // Within this loop, the file should be identified.
+        // Subsequent checks will only be done if the previous check
+        //   failed.
+        //-----------------------------------------------------------------
+        //-----------------------------------------------------------------
+        // \todo Check if the file should be ignored
+        //-----------------------------------------------------------------
+        if ( ( ( entry_cur->size( ) > 0 )
+               && ( (*entry_cur)[ 0 ] == '.' ) )
+             || ( ( entry_cur->size( ) >= tmp.size( ) )
+                  && ( entry_cur->compare( entry_cur->size( ) -
+                                           tmp.size( ),
+                                           std::string::npos,
+                                           tmp ) == 0 ) ) )
+        {
+            continue;
+        }
                      
-      //-----------------------------------------------------------------
-      /// \todo
-      /// Check if any registered indexing scheme indexes this type of
-      ///   file and if so, what assumption does it make about the file
-      ///   type.
-      //-----------------------------------------------------------------
-      dsd.s_filename = *entry_cur;
-      if ( diskCache::Cache::RegistrySingleton::ScanForMatch( dsd ) )
-      {
-        continue;
-      }
-      //-----------------------------------------------------------------
-      // Check for leaf optimization
-      //
-      // If the link count != 2, then this directory is not a leaf.
-      // If the link count == 2, then the directory is a leaf
-      //    When it is a leaf, then we skip the stat and hence
-      //    the check for symlink is also disabled.
-      //-----------------------------------------------------------------
-      if ( Stat.stat_buffer.st_nlink != 2 )
-      {
-          //-------------------------------------------------------------
-          /// \todo
-          /// Check if entry should be excluded from the scan.
-          /// \note
-          ///    This check assumes that patterns that match
-          ///    are not directories
-          //-------------------------------------------------------------
-          //-------------------------------------------------------------
-          // The following checks need to know the file type so a system
-          //   call is done.
-          //-------------------------------------------------------------
-          temp_file = Path;
-          temp_file += "/";
-          temp_file += *entry_cur;
+        //-----------------------------------------------------------------
+        /// \todo
+        /// Check if any registered indexing scheme indexes this type of
+        ///   file and if so, what assumption does it make about the file
+        ///   type.
+        //-----------------------------------------------------------------
+        dsd.s_filename = *entry_cur;
+        if ( diskCache::Cache::RegistrySingleton::ScanForMatch( dsd ) )
+        {
+            continue;
+        }
+        //-----------------------------------------------------------------
+        // Check for leaf optimization
+        //
+        // If the link count != 2, then this directory is not a leaf.
+        // If the link count == 2, then the directory is a leaf
+        //    When it is a leaf, then we skip the stat and hence
+        //    the check for symlink is also disabled.
+        //-----------------------------------------------------------------
+        if ( Stat.stat_buffer.st_nlink != 2 )
+        {
+            //-------------------------------------------------------------
+            /// \todo
+            /// Check if entry should be excluded from the scan.
+            /// \note
+            ///    This check assumes that patterns that match
+            ///    are not directories
+            //-------------------------------------------------------------
+            //-------------------------------------------------------------
+            // The following checks need to know the file type so a system
+            //   call is done.
+            //-------------------------------------------------------------
+            temp_file = Path;
+            temp_file += "/";
+            temp_file += *entry_cur;
           
-          struct stat stat_struct;
-          do_stat( temp_file, stat_struct, false );
+            struct stat stat_struct;
+            do_stat( temp_file, stat_struct, false );
 
-          if ( S_ISLNK( stat_struct.st_mode ) )
-          {
-              throw SymbolicLinkError( temp_file, method_name );
-          }
-          if ( S_ISDIR( stat_struct.st_mode ) )
-          {
-              //---------------------------------------------------------
-              // Check to see if the directory should be excluded
-              //---------------------------------------------------------
-              if ( ExcludedDirectoriesSingleton::IsExcluded( *entry_cur ) )
-              {
-                  std::ostringstream    msg;
+            if ( S_ISLNK( stat_struct.st_mode ) )
+            {
+                throw SymbolicLinkError( temp_file, NULL );
+            }
+            if ( S_ISDIR( stat_struct.st_mode ) )
+            {
+                //---------------------------------------------------------
+                // Check to see if the directory should be excluded
+                //---------------------------------------------------------
+                if ( ExcludedDirectoriesSingleton::IsExcluded( *entry_cur ) )
+                {
+                    std::ostringstream    msg;
 
-                  msg << "Excluding directory: " << temp_file
-                      ;
-                  GenericAPI::queueLogEntry( msg.str( ),
-                                             GenericAPI::LogEntryGroup_type::MT_NOTE,
-                                             0,
-                                             method_name,
-                                             "CXX_INTERFACE" );
-                  IgnoredDirectories.insert( *entry_cur );
-                  continue;
-              }
-              //---------------------------------------------------------
-              /// \todo
-              /// Add to the list of directories
-              //---------------------------------------------------------
-              Children.push_back( directory_element_type( *entry_cur, false ) );
-              continue;
-          }
-          //-------------------------------------------------------------
-          // Everything else is a file that is unmanaged.
-          //-------------------------------------------------------------
+                    msg << "Excluding directory: " << temp_file
+                        ;
+                    GenericAPI::queueLogEntry( msg.str( ),
+                                               GenericAPI::LogEntryGroup_type::MT_NOTE,
+                                               0,
+                                               method_name,
+                                               "CXX_INTERFACE" );
+                    IgnoredDirectories.insert( *entry_cur );
+                    continue;
+                }
+                //---------------------------------------------------------
+                /// \todo
+                /// Add to the list of directories
+                //---------------------------------------------------------
+                Children.push_back( directory_element_type( *entry_cur, false ) );
+                continue;
+            }
+            //-------------------------------------------------------------
+            // Everything else is a file that is unmanaged.
+            //-------------------------------------------------------------
+        }
+      }
+      catch( const SymbolicLinkError& Except )
+      {
+          QUEUE_LOG_MESSAGE( Except.what( ),
+                             MT_NOTE,
+                             0,
+                             method_name,
+                             "CXX_INTERFACE" );
+          continue;
       }
       
-    }
+    } // for
     //-------------------------------------------------------------------
     // Now have all search engines do any necessary cleanup.
     //-------------------------------------------------------------------
