@@ -1,10 +1,15 @@
 #include <ldas_tools_config.h>
 
 #include <sys/select.h>
+#include <sys/stat.h>
+#include <sys/time.h>
 
 #include <ctype.h>
+#include <unistd.h>
 
 #include <algorithm>
+#include <list>
+#include <map>
 
 #include "ldastoolsal/SignalHandler.hh"
 
@@ -25,7 +30,6 @@
 #include "MountPointScanner.hh"
 #include "ScanMountPointsDaemon.hh"
 
-using GenericAPI::queueLogEntry;
 using LDASTools::AL::CommandLineOptions;
 
 using diskCache::Commands::updateFileExtList;
@@ -71,6 +75,42 @@ namespace
 
     return retval;
   }
+
+  void
+  order_by_access( std::list< std::string >& Paths )
+  {
+    typedef std::multimap< time_t, std::string > op_type;
+    typedef std::list< std::string > paths_type;
+
+    op_type ordered_paths;
+
+    struct stat		stat_buf;
+
+    for ( paths_type::const_iterator
+	    cur = Paths.begin( ),
+	    last = Paths.end( );
+	  cur != last;
+	  ++cur )
+    {
+      GenericAPI::Stat( *cur, stat_buf );
+      
+      ordered_paths.insert( op_type::value_type( stat_buf.st_mtime, *cur ) );
+    }
+
+    paths_type	new_paths;
+
+    for( op_type::const_reverse_iterator
+	   cur = ordered_paths.rbegin( ),
+	   last = ordered_paths.rend( );
+	 cur != last;
+	 ++cur )
+    {
+      new_paths.push_back( cur->second );
+    }
+
+    Paths.swap( new_paths );
+  }
+
 } // namespace - anonymous
 namespace diskCache
 {
@@ -128,7 +168,11 @@ namespace diskCache
       {
       case NON_BLOCK:
       case BLOCK_DAEMON:
-	if ( Key.compare( "CONCURRENCY" ) == 0 )
+	if ( Key.compare( "CACHE_WRITE_DELAY_SECS" ) == 0 )
+	{
+	  command.cache_write_delay( Value );
+	}
+	else if ( Key.compare( "CONCURRENCY" ) == 0 )
 	{
 	  command.set_concurrency( Value );
 	}
@@ -352,6 +396,7 @@ namespace diskCache
 	    const std::string& DefaultConfigurationFilename,
 	    bool Seedable )
       : m_args( Args ),
+	cache_write_delay_( 120 ),
 	m_concurrency( 4 ),
 	scan_interval( 16000 ),
 	stat_timeout( 5 ),
@@ -492,25 +537,75 @@ namespace diskCache
 	  }
 	}
       }
-      setup_variables( );
+      //-----------------------------------------------------------------
+      // Check for seeding
+      //-----------------------------------------------------------------
       if ( ( Seedable )
 	   && ( output_binary.empty( ) == false ) )
       {
+	std::list< std::string >	paths;
+
+	paths.push_back( output_binary );
+	paths.push_back( ( output_binary + ".bak") );
+	paths.push_back( ( output_binary + "#Resync#" ) );
+
+	::order_by_access( paths );		 
+
 	//---------------------------------------------------------------
 	// Seed the cache with previous binary
 	//---------------------------------------------------------------
-	try
+	for ( std::list< std::string >::const_iterator
+		cur_path = paths.begin( ),
+		last_path = paths.end( );
+	      cur_path != last_path;
+	      ++cur_path )
 	{
-	  LDASTools::AL::ifstream	ifs( output_binary.c_str( ) );
-	  diskCache::Streams::IBinary	stream( ifs );
+	  try
+	  {
+	    QUEUE_LOG_MESSAGE( "Trying to seed the cache with: " << *cur_path,
+			       MT_NOTE,
+			       0,
+			       "Daemon::Daemon",
+			       "CXX" );
 
-	  diskCache::Read( stream );
-	  ifs.close( );
-	}
-	catch( ... )
-	{
+	    LDASTools::AL::ifstream	ifs( cur_path->c_str( ) );
+	    diskCache::Streams::IBinary	stream( ifs );
+
+	    try
+	    {
+	      diskCache::Read( stream );
+	    }
+	    catch( ... )
+	    {
+	      ifs.close( );
+	      continue;
+	    }
+	    ifs.close( );
+	    //-----------------------------------------------------------
+	    // Was able to seed with the given file so terminate
+	    //   loop of files to try.
+	    //-----------------------------------------------------------
+	    QUEUE_LOG_MESSAGE( "Succeeded to seed the cache with: "
+			       << *cur_path,
+			       MT_NOTE,
+			       0,
+			       "Daemon::Daemon",
+			       "CXX" );
+	    break;
+	  }
+	  catch( ... )
+	  {
+	    //-----------------------------------------------------------
+	    // Something wrong with reading so advance to next
+	    //   file to try.
+	    //-----------------------------------------------------------
+	  }
 	}
       }
+      //-----------------------------------------------------------------
+      // Set variables once cache is seeded (ticket #2167)
+      //-----------------------------------------------------------------
+      setup_variables( );
     }
 
     //-------------------------------------------------------------------
@@ -541,12 +636,26 @@ namespace diskCache
     {
       using LDASTools::AL::SignalHandler;
 
+      static const char* method = "Daemon::ResetOnSignal";
+
       if ( Value )
       {
+	QUEUE_LOG_MESSAGE( "Registering SIGNAL_HANGUP handler",
+			   MT_NOTE,
+			   0,
+			   method,
+			   "CXX" );
 	SignalHandler::Register( this, SignalHandler::SIGNAL_HANGUP );
+	SignalCapture( SignalHandler::SIGNAL_HANGUP );
       }
       else
       {
+	QUEUE_LOG_MESSAGE( "Unregistering SIGNAL_HANGUP handler",
+			   MT_NOTE,
+			   0,
+			   method,
+			   "CXX" );
+	SignalIgnore( SignalHandler::SIGNAL_HANGUP );
 	SignalHandler::Unregister( this, SignalHandler::SIGNAL_HANGUP );
       }
     }
@@ -554,6 +663,13 @@ namespace diskCache
     void Daemon::
     SignalCallback( signal_type Signal )
     {
+      static const char* method = "Daemon::SignalCallback";
+      QUEUE_LOG_MESSAGE( "Calling Daemon::SignalCallback"
+			 << " with signal: " << Signal,
+			 MT_NOTE,
+			 0,
+			 method,
+			 "CXX" );
       if ( Signal == LDASTools::AL::SignalHandler::SIGNAL_HANGUP )
       {
 	//---------------------------------------------------------------
@@ -599,11 +715,11 @@ namespace diskCache
 	  }
 	  if ( FD_ISSET( server->handle( ), &sset ) )
 	  {
-	    queueLogEntry( "Server: waiting for client request",
-			   GenericAPI::LogEntryGroup_type::MT_DEBUG,
-			   30,
-			   method_name,
-			   "CXX" );
+	    QUEUE_LOG_MESSAGE( "Server: waiting for client request",
+			       MT_DEBUG,
+			       30,
+			       method_name,
+			       "CXX" );
 	    client = server->accept( );
 
 	    if ( client->good( ) )
@@ -612,11 +728,11 @@ namespace diskCache
 	      Join( );
 	    }
 
-	    queueLogEntry( "Server: client request completed",
-			   GenericAPI::LogEntryGroup_type::MT_DEBUG,
-			   30,
-			   method_name,
-			   "CXX" );
+	    QUEUE_LOG_MESSAGE( "Server: client request completed",
+			       MT_DEBUG,
+			       30,
+			       method_name,
+			       "CXX" );
 	    client.reset( ( server_responce_type::element_type* )NULL );
 	  }
 	}
@@ -728,15 +844,23 @@ namespace diskCache
 
       if ( ! server )
       {
+	std::cin.clear( );
 	std::cin.getline( Buffer, BufferSize, '\n' );
 	retval = ( ( std::cin.good( ) )
 		  ? true
 		  : false );
-		    
       }
       return retval;
     }
 
+    inline void Daemon::
+    cache_write_delay( const std::string& Value )
+    {
+      std::istringstream	s( Value );
+
+      s >> cache_write_delay_;
+    }
+
     inline void Daemon::
     set_concurrency( const std::string& Value )
     {
@@ -928,14 +1052,11 @@ namespace diskCache
 	// Add the extensions
 	//---------------------------------------------------------------
 	{
-	  std::ostringstream	msg;
-	  msg << "Adding extension: " << m_extensions.size( )
-	    ;
-	  queueLogEntry( msg.str( ),
-			 GenericAPI::LogEntryGroup_type::MT_NOTE,
-			 0,
-			 "Daemon::setup_variables",
-			 "CXX" );
+	  QUEUE_LOG_MESSAGE( "Adding extension: " << m_extensions.size( ),
+			     MT_NOTE,
+			     0,
+			     "Daemon::setup_variables",
+			     "CXX" );
 	}
 	updateFileExtList( m_extensions );
       }
@@ -947,30 +1068,24 @@ namespace diskCache
 	// Add the mount points
 	//---------------------------------------------------------------
 	{
-	  std::ostringstream	msg;
-	  msg << "Adding mount points: " << m_mount_points.size( )
-	    ;
-	  queueLogEntry( msg.str( ),
-			 GenericAPI::LogEntryGroup_type::MT_NOTE,
-			 0,
-			 "Daemon::setup_variables",
-			 "CXX" );
+	  QUEUE_LOG_MESSAGE( "Adding mount points: " << m_mount_points.size( ),
+			     MT_NOTE,
+			     0,
+			     "Daemon::setup_variables",
+			     "CXX" );
 	}
 	MountPointManagerSingleton::UpdateResults    status;
 
 	updateMountPtList( status, m_mount_points, false );
 	{
-	  std::ostringstream	msg;
-	  msg << "Added mount points status:"
-	      << " added: " << status.s_added.size( )
-	      << " deleted: " << status.s_deleted.size( )
-	      << " errors: " << status.s_errors.size( )
-	    ;
-	  queueLogEntry( msg.str( ),
-			 GenericAPI::LogEntryGroup_type::MT_NOTE,
-			 0,
-			 "Daemon::setup_variables",
-			 "CXX" );
+	  QUEUE_LOG_MESSAGE( "Added mount points status:"
+			     << " added: " << status.s_added.size( )
+			     << " deleted: " << status.s_deleted.size( )
+			     << " errors: " << status.s_errors.size( ),
+			     MT_NOTE,
+			     0,
+			     "Daemon::setup_variables",
+			     "CXX" );
 	}
       }
 
@@ -1001,6 +1116,24 @@ namespace diskCache
       //-----------------------------------------------------------------
       // Update the cache files
       //-----------------------------------------------------------------
+      {
+	QUEUE_LOG_MESSAGE( "Checking to if cache delay should be set: "
+			   << (Mask & VAR_CACHE_WRITE_DELAY),
+			   MT_NOTE,
+			   0,
+			   "Daemon::setup_variables",
+			   "CXX" );
+      }
+      if ( Mask & VAR_CACHE_WRITE_DELAY )
+      {
+	QUEUE_LOG_MESSAGE( "Setting CACHE_WRITE_DELAY: " << cache_write_delay_,
+			   MT_NOTE,
+			   0,
+			   "Daemon::setup_variables",
+			   "CXX" );
+	diskCache::DumpCacheDaemon::Interval( cache_write_delay_ * 1000 );
+      }
+
       if ( ( Mask & VAR_OUTPUT_ASCII ) && ( output_ascii.size( ) > 0 ) )
       {
 	diskCache::DumpCacheDaemon::FilenameAscii( output_ascii );
@@ -1037,15 +1170,13 @@ namespace diskCache
       //-----------------------------------------------------------------
       if ( ! configuration_filename.empty( ) )
       {
-	std::ostringstream	msg;
-	msg << "Rereading configuration file: "
-	    << configuration_filename
-	  ;
-	queueLogEntry( msg.str( ),
-		       GenericAPI::LogEntryGroup_type::MT_NOTE,
-		       0,
-		       method_name,
-		       "CXX" );
+	QUEUE_LOG_MESSAGE( "Rereading configuration file: "
+			   << configuration_filename
+			   ,
+			   MT_NOTE,
+			   0,
+			   method_name,
+			   "CXX" );
 	Config_		cfg( *this );
 	std::ifstream	stream( configuration_filename.c_str( ) );
       
