@@ -485,6 +485,15 @@ namespace diskCache
       {
 	mp[ *cur ] = root_type( new root_type::element_type( *cur ) );
       }
+#else
+      for ( mount_point_name_container_type::const_iterator
+	      cur = deleted.begin( ),
+	      last = deleted.end( );
+	    cur != last;
+	    ++cur )
+      {
+	m_directory_cache->RemoveDirectoryRecursively( *cur );
+      }
 #endif /* ! NEW_DIRECTORY_INTERFACE */
       //-----------------------------------------------------------------
       // Update the information returned to the user
