@@ -47,6 +47,32 @@ namespace FrameCPP
     {
     }
 
+    //-----------------------------------------------------------------------
+    /// Loop over members of the table of contents to gather information
+    /// requested by the caller.
+    //-----------------------------------------------------------------------
+    void FrTOC::
+    ForEach( query_info_type Info, FunctionBase& Action  ) const
+    {
+      switch( Info )
+      {
+      case TOC_CHANNEL_NAMES:
+	//-------------------------------------------------------------------
+	/// \todo Need to finish the list of channel names
+	//-------------------------------------------------------------------
+	FrTOCAdcData::forEach( Info, Action );
+	FrTOCProcData::forEach( Info, Action );
+	FrTOCSimData::forEach( Info, Action );
+	break;
+      case TOC_DETECTOR:
+	FrTOCData::forEach( Info, Action );
+	break;
+      case TOC_FR_STRUCTS:
+	FrTOCData::forEach( Info, Action );
+	break;
+      }
+    }
+
     void FrTOC::
     FrStatDataQuery( const std::string& NamePattern,
 		     const LDASTools::AL::GPSTime& StartTime,
