@@ -80,6 +80,7 @@ namespace FrameCPP
 	//-------------------------------------------------------------------
 	FrTOCAdcData::forEach( Info, Action );
 	FrTOCProcData::forEach( Info, Action );
+	FrTOCSimData::forEach( Info, Action );
 	break;
       case TOC_DETECTOR:
 	FrTOCData::forEach( Info, Action );
@@ -816,26 +817,42 @@ namespace FrameCPP
     const FrTOC& FrTOC::
     operator=( const FrTOC& Source )
     {
+      FrTOCData::operator=( Source );
+      FrTOCStatData::operator=( Source );
       FrTOCAdcData::operator=( Source );
       FrTOCData::operator=( Source );
-      FrTOCEvent::operator=( Source );
       FrTOCProcData::operator=( Source );
+      FrTOCSimData::operator=( Source );
       FrTOCSerData::operator=( Source );
-      FrTOCSimEvent::operator=( Source );
       FrTOCSummary::operator=( Source );
+      FrTOCEvent::operator=( Source );
+      FrTOCSimEvent::operator=( Source );
+
+      m_StatType = Source.m_StatType;
+
       return *this;
     }
 
     const FrTOC& FrTOC::
     operator=( const Previous::FrTOC& Source )
     {
+      FrTOCData::operator=( Source );
+      FrTOCStatData::operator=( Source );
       FrTOCAdcData::operator=( Source );
       FrTOCData::operator=( Source );
-      FrTOCEvent::operator=( Source );
       FrTOCProcData::operator=( Source );
+      FrTOCSimData::operator=( Source );
       FrTOCSerData::operator=( Source );
-      FrTOCSimEvent::operator=( Source );
       FrTOCSummary::operator=( Source );
+      FrTOCEvent::operator=( Source );
+      FrTOCSimEvent::operator=( Source );
+
+#if WORKING
+      /// \todo
+      ///     Need to properly promote m_StatType from previous
+      m_StatType = Source.m_StatType;
+#endif /* WORKING */
+
       return *this;
     }
 
