@@ -56,6 +56,16 @@ enum {
   EXIT_CODE_VECTOR_EXPANSION
 };
 
+class channel_name_constructor
+  : public FrameCPP::Common::FrTOC::FunctionString,
+    public std::list< std::string >
+{
+public:
+  virtual ~channel_name_constructor( );
+
+  virtual void operator()( const std::string& ChannelName );
+};
+
 inline void
 depart( int ExitCode )
 {
@@ -199,6 +209,12 @@ public:
     return m_channels;
   }
 
+  inline bool
+  ListChannels( ) const
+  {
+    return list_channels;
+  }
+
   inline bool
   Raw( ) const
   {
@@ -223,17 +239,20 @@ private:
   enum option_types {
     OPT_CHANNEL,
     OPT_HELP,
+    OPT_LIST_CHANNELS,
     OPT_RAW
   };
 
   OptionSet			m_options;
   channel_container_type	m_channels;
+  bool				list_channels;
   bool				m_raw;
 };
 
 CommandLine::
 CommandLine( int ArgC, char** ArgV )
   : CommandLineOptions( ArgC, ArgV ),
+    list_channels( false ),
     m_raw( false )
 {
   //---------------------------------------------------------------------
@@ -268,6 +287,13 @@ CommandLine( int ArgC, char** ArgV )
 		 Option::ARG_NONE,
 		 "Display this message" ) );
 
+  //:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
+  m_options.
+    Add( Option( OPT_LIST_CHANNELS,
+		 "list-channels",
+		 Option::ARG_NONE,
+		 "Display a list of channels." ) );
+
   //:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
   desc.str( "" );
   desc <<
@@ -310,6 +336,9 @@ CommandLine( int ArgC, char** ArgV )
       case OPT_CHANNEL:
 	m_channels.push_back( arg_value );
 	break;
+      case OPT_LIST_CHANNELS:
+	list_channels = true;
+	break;
       case OPT_RAW:
 	m_raw = true;
 	break;
@@ -355,135 +384,168 @@ try
 
     std::cout << "Frame file: " << filename << std::endl
       ;
-    for ( CommandLine::channel_container_type::const_iterator
-	    cur = cl.Channels( ).begin( ),
-	    last = cl.Channels( ).end( ); 
-	  cur != last;
-	  ++cur )
+    //-------------------------------------------------------------------
+    //
+    //-------------------------------------------------------------------
+    if ( cl.ListChannels( ) )
     {
       //-----------------------------------------------------------------
-      // FrAdcData
+      // Get the channels from the table of contents
       //-----------------------------------------------------------------
-      {
-	LDASTools::AL::SharedPtr< FrAdcData >	channel;
+      const Common::FrTOC*	toc( ifs.GetTOC( ) );
+      channel_name_constructor	cn;
 
-	try
-	{
-	  channel = ifs.ReadFrAdcData( 0, *cur );
-	}
-	catch( ... )
-	{
-	}
-	if ( channel )
-	{
-	  dump_vect( channel->RefData( )[ 0 ], cl );
-	  continue;
-	}
+      if ( toc != (const FrTOC*)NULL )
+      {
+	toc->ForEach( FrameCPP::Common::FrTOC::TOC_CHANNEL_NAMES, cn );
       }
       //-----------------------------------------------------------------
-      // FrProcData
+      // Make it easier on output by sorting the channel names
       //-----------------------------------------------------------------
+      cn.sort( );
+      //-----------------------------------------------------------------
+      // List the channels
+      //-----------------------------------------------------------------
+      for ( channel_name_constructor::const_iterator
+	      cur = cn.begin( ),
+	      last = cn.end( );
+	    cur != last;
+	    ++cur )
       {
-	LDASTools::AL::SharedPtr< FrProcData >	channel;
-
-        try
-	{
-	  channel = ifs.ReadFrProcData( 0, *cur );
-	}
-	catch( ... )
-	{
-	}
-	if ( channel )
-	{
-	  dump_vect( channel->RefData( )[ 0 ], cl );
-	  continue;
-	}
-      }
-      //-----------------------------------------------------------------
-      // FrEvent
-      //-----------------------------------------------------------------
-      {
-	LDASTools::AL::SharedPtr< FrEvent >	channel;
-
-	try
-	{
-	  channel = ifs.ReadFrEvent( 0, *cur );
-	}
-	catch( ... )
-	{
-	}
-	if ( channel )
-	{
-	  dump_vect( channel->RefData( )[ 0 ], cl );
-	  continue;
-	}
-      }
-      //-----------------------------------------------------------------
-      // FrSerData
-      //-----------------------------------------------------------------
-      {
-	LDASTools::AL::SharedPtr< FrSerData >	channel;
-
-	try
-	{
-	  channel = ifs.ReadFrSerData( 0, *cur );
-	}
-	catch( ... )
-	{
-	}
-	if ( channel )
-	{
-	  dump_vect( channel->RefSerial( )[ 0 ], cl );
-	  continue;
-	}
-      }
-      //-----------------------------------------------------------------
-      // FrSimData
-      //-----------------------------------------------------------------
-      {
-	LDASTools::AL::SharedPtr< FrSimData >	channel;
-
-	try
-	{
-	  channel = ifs.ReadFrSimData( 0, *cur );
-	}
-	catch( ... )
-	{
-	}
-	if ( channel )
-	{
-	  dump_vect( channel->RefData( )[ 0 ], cl );
-	  continue;
-	}
-      }
-      //-----------------------------------------------------------------
-      // FrSimEvent
-      //-----------------------------------------------------------------
-      {
-	LDASTools::AL::SharedPtr< FrSimEvent >	channel;
-
-	try
-	{
-	  channel = ifs.ReadFrSimEvent( 0, *cur );
-	}
-	catch( ... )
-	{
-	}
-	if ( channel )
-	{
-	  dump_vect( channel->RefData( )[ 0 ], cl );
-	  continue;
-	}
-      }
-      //-----------------------------------------------------------------
-      // Case where the channel was not found
-      //-----------------------------------------------------------------
-      if ( exit_code == EXIT_CODE_OK)
-      {
-	exit_code = EXIT_CODE_UNKNOWN_CHANNEL;
+	std::cout << "\t" << *cur << std::endl;
       }
     }
+    else
+    {
+      for ( CommandLine::channel_container_type::const_iterator
+	      cur = cl.Channels( ).begin( ),
+	      last = cl.Channels( ).end( ); 
+	    cur != last;
+	    ++cur )
+      {
+	//-----------------------------------------------------------------
+	// FrAdcData
+	//-----------------------------------------------------------------
+	{
+	  LDASTools::AL::SharedPtr< FrAdcData >	channel;
 
+	  try
+	  {
+	    channel = ifs.ReadFrAdcData( 0, *cur );
+	  }
+	  catch( ... )
+	  {
+	  }
+	  if ( channel )
+	  {
+	    dump_vect( channel->RefData( )[ 0 ], cl );
+	    continue;
+	  }
+	}
+	//-----------------------------------------------------------------
+	// FrProcData
+	//-----------------------------------------------------------------
+	{
+	  LDASTools::AL::SharedPtr< FrProcData >	channel;
+
+	  try
+	  {
+	    channel = ifs.ReadFrProcData( 0, *cur );
+	  }
+	  catch( ... )
+	  {
+	  }
+	  if ( channel )
+	  {
+	    dump_vect( channel->RefData( )[ 0 ], cl );
+	    continue;
+	  }
+	}
+	//-----------------------------------------------------------------
+	// FrEvent
+	//-----------------------------------------------------------------
+	{
+	  LDASTools::AL::SharedPtr< FrEvent >	channel;
+
+	  try
+	  {
+	    channel = ifs.ReadFrEvent( 0, *cur );
+	  }
+	  catch( ... )
+	  {
+	  }
+	  if ( channel )
+	  {
+	    dump_vect( channel->RefData( )[ 0 ], cl );
+	    continue;
+	  }
+	}
+	//-----------------------------------------------------------------
+	// FrSerData
+	//-----------------------------------------------------------------
+	{
+	  LDASTools::AL::SharedPtr< FrSerData >	channel;
+
+	  try
+	  {
+	    channel = ifs.ReadFrSerData( 0, *cur );
+	  }
+	  catch( ... )
+	  {
+	  }
+	  if ( channel )
+	  {
+	    dump_vect( channel->RefSerial( )[ 0 ], cl );
+	    continue;
+	  }
+	}
+	//-----------------------------------------------------------------
+	// FrSimData
+	//-----------------------------------------------------------------
+	{
+	  LDASTools::AL::SharedPtr< FrSimData >	channel;
+
+	  try
+	  {
+	    channel = ifs.ReadFrSimData( 0, *cur );
+	  }
+	  catch( ... )
+	  {
+	  }
+	  if ( channel )
+	  {
+	    dump_vect( channel->RefData( )[ 0 ], cl );
+	    continue;
+	  }
+	}
+	//-----------------------------------------------------------------
+	// FrSimEvent
+	//-----------------------------------------------------------------
+	{
+	  LDASTools::AL::SharedPtr< FrSimEvent >	channel;
+
+	  try
+	  {
+	    channel = ifs.ReadFrSimEvent( 0, *cur );
+	  }
+	  catch( ... )
+	  {
+	  }
+	  if ( channel )
+	  {
+	    dump_vect( channel->RefData( )[ 0 ], cl );
+	    continue;
+	  }
+	}
+	//-----------------------------------------------------------------
+	// Case where the channel was not found
+	//-----------------------------------------------------------------
+	if ( exit_code == EXIT_CODE_OK)
+	{
+	  exit_code = EXIT_CODE_UNKNOWN_CHANNEL;
+	}
+      }
+    }
   }
   //---------------------------------------------------------------------
   // Exit
@@ -575,3 +637,15 @@ dump_vect( vector_type Vect, const CommandLine& Options )
   }
   std::cout << std::endl;
 }
+
+channel_name_constructor::
+~channel_name_constructor( )
+{
+}
+
+void channel_name_constructor::
+operator()( const std::string& ChannelName )
+{
+  push_back( ChannelName );
+}
+
