@@ -187,6 +187,44 @@ namespace FrameAPI
 {
    namespace RDS
    {
+      MissingChannel::
+      MissingChannel( const std::string& ChannelName )
+	 : std::runtime_error( create_error_msg( ChannelName ) )
+      {
+      }
+
+      MissingChannel::
+      MissingChannel( const std::string& ChannelName,
+		      const LDASTools::AL::GPSTime& Start,
+		      const LDASTools::AL::GPSTime& Stop )
+	 : std::runtime_error( create_error_msg( ChannelName, Start, Stop ) )
+      {
+      }
+
+      std::string MissingChannel::
+      create_error_msg( const std::string& ChannelName )
+      {
+	 std::ostringstream	retval;
+
+	 retval << "Missing channel: " << ChannelName
+	    ;
+	 return retval.str( );
+      }
+
+      std::string MissingChannel::
+      create_error_msg( const std::string& ChannelName,
+			const LDASTools::AL::GPSTime& Start,
+			const LDASTools::AL::GPSTime& Stop )
+      {
+	 std::ostringstream	retval;
+
+	 retval << "Unable to locate the channel named: " << ChannelName
+		<< " in any of the input frames for the time range: "
+		<< Start << " - " << Stop
+	    ;
+	 return retval.str( );
+      }
+
       Options::
       Options( )
 	 : history_record( true ),
@@ -584,12 +622,7 @@ RetrieveChannel( const std::string& Channel,
    //--------------------------------------------------------------------
    // No channel was located, time to throw an excpetion
    //--------------------------------------------------------------------
-   std::ostringstream	error;
-
-   error << "Unable to locate the channel named: " << Channel
-	 << " in any of the input frames for the time range: "
-	 << Start << " - " << ( Start + orig_dt );
-   throw std::runtime_error( error.str( ) );
+   throw FrameAPI::RDS::MissingChannel( Channel, Start, ( Start + orig_dt ) );
 }
 
 
@@ -600,6 +633,20 @@ RetrieveChannels( frame_h_type& Frame,
 		  const REAL_8 DeltaT,
 		  const RDSFrame::Options& Options )
 {
+   static const char* caller = "RDSFrame::private_type::RetrieveChannels";
+
+   if ( Frame )
+   {
+      QUEUE_LOG_MESSAGE( "Frame: " << Frame->GetName( )
+			 << " FrAdcData Entries: "  << ( ( Frame->GetRawData( ) )
+							 ? Frame->GetRawData( )->RefFirstAdc( ).size( )
+							 : 0 )
+			 << " FrProcData: " << Frame->RefProcData( ).size( )
+			 ,
+			 MT_DEBUG, 40,
+			 caller,
+			 "CreateRDS" );
+   }
    //--------------------------------------------------------------------
    // Reset the dynamic parts of the channel entry
    //--------------------------------------------------------------------
@@ -659,6 +706,15 @@ RetrieveChannels( frame_h_type& Frame,
       min_start_time = cur_start_time + cur_dt;
       PurgeFilesOlderThan( cur_start_time );
    }
+   QUEUE_LOG_MESSAGE( "Frame: " << Frame->GetName( )
+		      << " FrAdcData Entries: "  << ( ( Frame->GetRawData( ) )
+						      ? Frame->GetRawData( )->RefFirstAdc( ).size( )
+						      : 0 )
+		      << " FrProcData: " << Frame->RefProcData( ).size( )
+		      ,
+		      MT_DEBUG, 40,
+		      caller,
+		      "CreateRDS" );
 }
 
 inline INT_4U RDSFrame::private_type::
@@ -901,6 +957,15 @@ ProcessRequest( stream_type Output )
 	 m_p->RetrieveChannels( mResultFrame, *this,
 				frame_start, data_dt,
 				m_options );
+	 QUEUE_LOG_MESSAGE( "Frame: " << mResultFrame->GetName( )
+			    << " FrAdcData Entries: "  << ( ( mResultFrame->GetRawData( ) )
+							    ? mResultFrame->GetRawData( )->RefFirstAdc( ).size( )
+							    : 0 )
+			    << " FrProcData: " << mResultFrame->RefProcData( ).size( )
+			    ,
+			    MT_DEBUG, 30,
+			    "RDSFrame::ProcessRequest",
+			    "CreateRDS" );
 	 //--------------------------------------------------------------
 	 // Post process the concatinated data
 	 //--------------------------------------------------------------
@@ -939,6 +1004,15 @@ ProcessRequest( stream_type Output )
 	       throw SWIGEXCEPTION( msg.str() );   
 	    }
 	 }
+	 QUEUE_LOG_MESSAGE( "Frame(after): " << mResultFrame->GetName( )
+			    << " FrAdcData Entries: "  << ( ( mResultFrame->GetRawData( ) )
+							    ? mResultFrame->GetRawData( )->RefFirstAdc( ).size( )
+							    : 0 )
+			    << " FrProcData: " << mResultFrame->RefProcData( ).size( )
+			    ,
+			    MT_DEBUG, 30,
+			    "RDSFrame::ProcessRequest",
+			    "CreateRDS" );
 	 if ( mResultFrame.get( ) )
 	 {
 	    //----------------------------------------------------------
@@ -1110,6 +1184,21 @@ closeFrameFile( const std::string& Filename, bool Final )
 void RDSFrame::
 writeFrameToStream( )
 {
+   static const char* caller = "RDSFrame::writeFrameToStream";
+
+   QUEUE_LOG_MESSAGE( "Writing frame"
+		      << " with: " << ( ( mResultFrame->GetRawData( ) )
+					? mResultFrame->GetRawData( )->RefFirstAdc( ).size( )
+					: 0 )
+		      << " FrAdcData structures"
+		      << " with: " << mResultFrame->RefProcData( ).size( )
+		      << " FrProcData structures"
+		      << " allow duplicate FrProcData names: " << mResultFrame->RefProcData( ).AllowDuplicates( )
+		      ,
+		      MT_DEBUG, 30,
+		      caller,
+		      "RDSFrame" );
+
    m_stream->Write( mResultFrame,
 		    m_options.CompressionMethod( ),
 		    m_options.CompressionLevel( ),
