@@ -2,7 +2,6 @@
 #include <sys/stat.h>
 
 #include <fcntl.h>
-#include <signal.h>
 #include <sys/stat.h>
 #include <time.h>
 
@@ -21,6 +20,7 @@
 using LDASTools::AL::MemChecker;
 using LDASTools::AL::MutexLock;
 using LDASTools::AL::ReadWriteLock;
+using LDASTools::AL::SignalHandler;
 
 using LDASTools::AL::GPSTime;
 
@@ -31,9 +31,10 @@ using GenericAPI::MountPointStatus;
 using GenericAPI::queueLogEntry;
 
 #if 1
-#define CANCEL_SIGNAL SIGTERM
+#define USE_CANCEL_SIGNAL 1
+static const SignalHandler::signal_type CANCEL_SIGNAL = SignalHandler::SIGNAL_TERMINATE;
 #else
-#undef CANCEL_SIGNAL
+#undef USE_CANCEL_SIGNAL
 #endif /* 0 */
 
 //=======================================================================
@@ -692,7 +693,7 @@ action( )
     //-----------------------------------------------------------------
     // Setup to handle cancelation requests
     //-----------------------------------------------------------------
-#if CANCEL_SIGNAL
+#if USE_CANCEL_SIGNAL
     CancellationType( CANCEL_BY_SIGNAL, CANCEL_SIGNAL );
 #else
     //-------------------------------------------------------------------
@@ -729,7 +730,7 @@ action( )
 	  << " " << GPSTime::NowGPSTime( )
 	  << std::endl );
     }
-#if CANCEL_SIGNAL
+#if USE_CANCEL_SIGNAL
 #else
     pthread_cleanup_pop( 0 );
 #endif
