@@ -14,6 +14,9 @@
 
 #include "ldastoolsal/unittest.h"
 
+#include "genericAPI/LDASplatform.hh"
+#include "genericAPI/Logging.hh"
+#include "genericAPI/LogText.hh"
 #include "genericAPI/StatFork.hh"
 #include "genericAPI/StatPool.hh"
 #include "genericAPI/Stat.hh"
@@ -201,6 +204,10 @@ main( int ArgC, char** ArgV )
 {
   Test.Init(ArgC, ArgV);
 
+  GenericAPI::LoggingInfo::LogDirectory( "-" );
+  GenericAPI::SetLogFormatter( new GenericAPI::Log::Text( "" ) );
+  GenericAPI::LDASplatform::AppName( "tlstat" );
+
   char filename[ 2048 ];
 
   const char* abs_builddir( ::getenv( "ABS_BUILDDIR" ) );
