@@ -55,8 +55,14 @@ namespace LDASTools
 	line = trim( line );
 	std::string::size_type	pos;
 
-	if ( ( *(line.begin( )) == '[' )
-	     && ( *(line.end( ) - 1) == ']' ) )
+	if ( line.empty( ) ||
+	     ( *(line.begin( )) == '#' ) )
+	{
+	  // This is a comment
+	  continue;
+	}
+	else if ( ( *(line.begin( )) == '[' )
+		  && ( *(line.end( ) - 1) == ']' ) )
 	{
 	  line = line.substr( 1, line.size( ) - 2);
 	  line = trim( line );
