@@ -15,12 +15,13 @@
 #include <sstream>
 #include <string>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/Directory.hh"
 #include "ldastoolsal/mutexlock.hh"
 #include "ldastoolsal/Pool.hh"
 #include "ldastoolsal/SharedPtr.hh"
 #include "ldastoolsal/ErrorLog.hh"
+#include "ldastoolsal/Singleton.hh"
 #include "ldastoolsal/System.hh"
 #include "ldastoolsal/SystemCallTask.hh"
 #include "ldastoolsal/Timeout.hh"
@@ -670,7 +671,7 @@ namespace LDASTools
 
 namespace
 {
-  using LDASTools::AL::AtExit;
+  using LDASTools::AL::MemChecker;
 
   //---------------------------------------------------------------------
   //---------------------------------------------------------------------
@@ -679,9 +680,9 @@ namespace
   DirectoryPool::
   DirectoryPool( )
   {
-    AtExit::Append( singleton_suicide,
-		    "<anonymous>::DirectoryPool::singleton_suicide",
-		    5 );
+    MemChecker::Append( singleton_suicide,
+			"<anonymous>::DirectoryPool::singleton_suicide",
+			5 );
   }
 
   //---------------------------------------------------------------------
@@ -691,9 +692,9 @@ namespace
   DirectoryTrashPool::
   DirectoryTrashPool( )
   {
-    AtExit::Append( singleton_suicide,
-		    "<anonymous>::DirectoryTrashPool::singleton_suicide",
-		    5 );
+    MemChecker::Append( singleton_suicide,
+			"<anonymous>::DirectoryTrashPool::singleton_suicide",
+			5 );
   }
 
   int
