@@ -2,9 +2,9 @@
 
 #include <ldas_tools_config.h>
 
-#include <signal.h>
 #include <pthread.h>
 #include <unistd.h>
+#include <signal.h>	// pthread_kill
 
 #include <cassert>
 
@@ -18,6 +18,7 @@
 #include "ldastoolsal/ldasexception.hh"
 #include "ldastoolsal/ReadWriteLock.hh"
 #include "ldastoolsal/Thread.hh"
+#include "ldastoolsal/SignalHandler.hh"
 #include "ldastoolsal/Singleton.hh"
 
 #include "Thread.icc"
@@ -31,6 +32,7 @@ using LDASTools::AL::Thread;
 using LDASTools::AL::MemChecker;
 using LDASTools::AL::MutexLock;
 using LDASTools::AL::ReadWriteLock;
+using LDASTools::AL::SignalHandler;
 using LDASTools::AL::unordered_map;
 
 namespace {
@@ -43,12 +45,18 @@ namespace {
 
     return baton;
   }
-}
 
-static void
-wakeup( int SignalNumber )
-{
-  ::signal( SignalNumber, wakeup );
+  static class Wakeup_
+    : public SignalHandler::Callback
+  {
+  public:
+    typedef SignalHandler::signal_type signal_type;
+
+    virtual void
+    SignalCallback( signal_type Signal )
+    {
+    }
+  } wakeup;
 }
 
 class thread_registry
@@ -201,7 +209,7 @@ namespace LDASTools
     }
 
     Thread::cancel_type Thread::Self::
-    CancellationType( int& AuxInfo )
+    CancellationType( signal_type& Signal )
     {
       thread_registry::value_type v = NULL;
 
@@ -215,13 +223,13 @@ namespace LDASTools
       }
       if ( v )
       {
-	return v->CancellationType( AuxInfo );
+	return v->CancellationType( Signal );
       }
       return CANCEL_EXCEPTION;
     }
 
     void Thread::Self::
-    CancellationType( cancel_type Type, int AuxInfo )
+    CancellationType( cancel_type Type, signal_type Signal )
     {
       thread_registry::value_type v = NULL;
 
@@ -235,7 +243,7 @@ namespace LDASTools
       }
       if ( v )
       {
-	v->CancellationType( Type, AuxInfo );
+	v->CancellationType( Type, Signal );
 	v->CancellationEnable( ( Type != CANCEL_IGNORE ) );
       }
     }
@@ -251,7 +259,7 @@ namespace LDASTools
     Thread::
     Thread( )
       : p( new impl ),
-	m_cancel_via_signal( 0 ),
+	m_cancel_via_signal( SignalHandler::SIGNAL_UNKNOWN ),
 	m_cancel_state( false ),
 	m_cancel_thread( false ),
 	m_cancellation_type( CANCEL_IGNORE )
@@ -289,17 +297,18 @@ namespace LDASTools
 	m_cancel_thread = true;
 	switch( m_cancellation_type )
 	{
+	case CANCEL_ABANDON:
+	  Detach( );
+	  break;
 	case CANCEL_EXCEPTION:
 	case CANCEL_IGNORE:
 	  break;
 	case CANCEL_BY_SIGNAL:
 	  {
-	    int sig( m_cancel_via_signal );
-
-	    if ( sig > 0 )
+	    if ( m_cancel_via_signal != SignalHandler::SIGNAL_UNKNOWN )
 	    {
 	      l.Release( __FILE__, __LINE__ );
-	      Kill( sig );
+	      Kill( m_cancel_via_signal );
 	    }
 	  }
 	  break;
@@ -312,6 +321,9 @@ namespace LDASTools
 	    pthread_cancel( t );
 	  }
 	  break;
+	case CANCEL_UNKNOWN:
+	  // Should never happen
+	  break;
 	}
       }
     }
@@ -340,7 +352,9 @@ namespace LDASTools
       {
 	switch( m_cancellation_type )
 	{
+	case CANCEL_ABANDON:
 	case CANCEL_IGNORE:
+	case CANCEL_UNKNOWN:
 	  break;
 	case CANCEL_BY_SIGNAL:
 	case CANCEL_EXCEPTION:
@@ -363,17 +377,17 @@ namespace LDASTools
     }
 
     Thread::cancel_type Thread::
-    CancellationType( int& AuxInfo ) const
+    CancellationType( signal_type& Signal ) const
     {
       MutexLock	l( p->key, __FILE__, __LINE__ );
 
       switch( m_cancellation_type )
       {
       case CANCEL_BY_SIGNAL:
-	AuxInfo = m_cancel_via_signal;
+	Signal = m_cancel_via_signal;
 	break;
       default:
-	AuxInfo = 0;
+	Signal = SignalHandler::SIGNAL_UNKNOWN;
 	break;
       }
       return m_cancellation_type;
@@ -386,6 +400,18 @@ namespace LDASTools
 
       return m_cancel_thread;
     }
+    
+    void Thread::
+    SignalCapture( SignalHandler:: signal_type Sig )
+    {
+      SignalHandler::ThreadCaptureSignal( Sig );
+    }
+
+    void Thread::
+    SignalIgnore( SignalHandler:: signal_type Sig )
+    {
+      SignalHandler::ThreadIgnoreSignal( Sig );
+    }
 
     inline size_t Thread::
     StackSizeDefault( )
@@ -421,8 +447,10 @@ namespace LDASTools
       {
 	switch( m_cancellation_type )
 	{
+	case CANCEL_ABANDON:
 	case CANCEL_IGNORE:
 	case CANCEL_EXCEPTION:
+	case CANCEL_UNKNOWN:
 	  // Nothing to do to setup for this one
 	  break;
 	case CANCEL_BY_SIGNAL:
@@ -431,24 +459,9 @@ namespace LDASTools
 	    //---------------------------------------------------------
 	    // Make sure the signal handler is registered
 	    //---------------------------------------------------------
-	    wakeup( m_cancel_via_signal );
-	    //---------------------------------------------------------
-	    // Setup to cancel via signal.
-	    //---------------------------------------------------------
-	    sigset_t	signal_set;
-	    sigset_t	old_signal_set;
-
-	    sigemptyset( &signal_set );
-	    sigaddset( &signal_set, m_cancel_via_signal );
-
-	    //---------------------------------------------------------
-	    // Preserve the old signal mask
-	    //---------------------------------------------------------
-	    pthread_sigmask( SIG_SETMASK, NULL, &old_signal_set );
-	    //---------------------------------------------------------
-	    // Set the new signal mask
-	    //---------------------------------------------------------
-	    pthread_sigmask( SIG_UNBLOCK, &signal_set, NULL );
+	    SignalHandler::Register( &wakeup,
+				     m_cancel_via_signal );
+	    SignalHandler::ThreadCaptureSignal( m_cancel_via_signal );
 	  }
 	  break;
 	case CANCEL_ASYNCHRONOUS:
@@ -461,8 +474,10 @@ namespace LDASTools
       {
 	switch( m_cancellation_type )
 	{
+	case CANCEL_ABANDON:
 	case CANCEL_IGNORE:
 	case CANCEL_EXCEPTION:
+	case CANCEL_UNKNOWN:
 	  // Nothing to do to setup for this one
 	  break;
 	case CANCEL_BY_SIGNAL:
@@ -471,24 +486,9 @@ namespace LDASTools
 	    //-------------------------------------------------------------
 	    // Make sure the signal handler is registered
 	    //-------------------------------------------------------------
-	    wakeup( m_cancel_via_signal );
-	    //-------------------------------------------------------------
-	    // Setup to cancel via signal.
-	    //-------------------------------------------------------------
-	    sigset_t	signal_set;
-	    sigset_t	old_signal_set;
-
-	    sigemptyset( &signal_set );
-	    sigaddset( &signal_set, m_cancel_via_signal );
-
-	    //---------------------------------------------------------
-	    // Preserve the old signal mask
-	    //---------------------------------------------------------
-	    pthread_sigmask( SIG_SETMASK, NULL, &old_signal_set );
-	    //---------------------------------------------------------
-	    // Set the new signal mask
-	    //---------------------------------------------------------
-	    pthread_sigmask( SIG_BLOCK, &signal_set, NULL );
+	    SignalHandler::Register( &wakeup,
+				     m_cancel_via_signal );
+	    SignalHandler::ThreadCaptureSignal( m_cancel_via_signal );
 	  }
 	  break;
 	case CANCEL_ASYNCHRONOUS:
@@ -539,7 +539,7 @@ namespace LDASTools
     ///     CancellationEnable, CancellationCheck
     //---------------------------------------------------------------------
     void Thread::
-    CancellationType( cancel_type Type, int AuxInfo )
+    CancellationType( cancel_type Type, signal_type Signal )
     {
       MutexLock	l( p->key, __FILE__, __LINE__ );
     
@@ -548,7 +548,7 @@ namespace LDASTools
 		&& ( m_cancellation_type == Type ) )
 	   || ( ( Type == CANCEL_BY_SIGNAL )
 		&& ( m_cancellation_type == Type )
-		&& ( AuxInfo == m_cancel_via_signal ) ) )
+		&& ( Signal == m_cancel_via_signal ) ) )
       {
 	return;
       }
@@ -556,7 +556,7 @@ namespace LDASTools
       int oldstate;
 
       pthread_setcancelstate( PTHREAD_CANCEL_DISABLE, &oldstate );
-      m_cancel_via_signal = 0;
+      m_cancel_via_signal = SignalHandler::SIGNAL_UNKNOWN;
       m_cancellation_type = Type;
       switch( m_cancellation_type )
       {
@@ -567,10 +567,12 @@ namespace LDASTools
 	pthread_setcanceltype( PTHREAD_CANCEL_DEFERRED, &oldtype );
 	break;
       case CANCEL_BY_SIGNAL:
-	m_cancel_via_signal = AuxInfo;
+	m_cancel_via_signal = Signal;
 	break;
+      case CANCEL_ABANDON:
       case CANCEL_EXCEPTION:
       case CANCEL_IGNORE:
+      case CANCEL_UNKNOWN:
 	return;
 	break;
       }
@@ -607,7 +609,7 @@ namespace LDASTools
       // This signal does not disturb the process in any way.
       // Just want to determine if the process is still there.
       //-------------------------------------------------------------------
-      return ( Kill( 0 ) == 0 );
+      return ( Kill( SignalHandler::SIGNAL_ISALIVE ) == 0 );
     }
 
     bool Thread::
@@ -687,13 +689,13 @@ namespace LDASTools
     }
 
     int Thread::
-    Kill( int Signal ) const
+    Kill( signal_type Signal ) const
     {
       MutexLock	l( p->key, __FILE__, __LINE__ );
     
       if ( p->tid )
       {
-	return pthread_kill( p->tid, Signal );
+	return pthread_kill( p->tid, SignalHandler::OSSignal( Signal ) );
       }
       // Process could not be found since it is null
       return ESRCH;
@@ -798,9 +800,9 @@ namespace LDASTools
 	  {
 	    if ( ThreadSource->IsCancelled( ) )
 	    {
-	      int aux_info;
+	      signal_type sig;
 
-	      switch( ThreadSource->CancellationType( aux_info ) )
+	      switch( ThreadSource->CancellationType( sig ) )
 	      {
 	      case CANCEL_ASYNCHRONOUS:
 	      case CANCEL_DEFERRED:
