@@ -1,33 +1,42 @@
 #include <ldas_tools_config.h>
 
 #include <sys/time.h>
-#include <signal.h>
 #include <unistd.h>
+#include <signal.h>	// pthread_kill
 
 #include <sstream>
 
 #include "ldastoolsal/AtExit.hh"
 #include "ldastoolsal/ErrorLog.hh"
+#include "ldastoolsal/SignalHandler.hh"
 #include "ldastoolsal/TimerThread.hh"
 
 #define CONDITIONAL_WAIT	0
 #define USE_NANOSLEEP		1
 #define	USE_ALARM		0
 
-#define WAITER_SIGNAL SIGUSR1
 
 using LDASTools::AL::GPSTime;
 using LDASTools::AL::ErrorLog;
 using LDASTools::AL::StdErrLog;
+using LDASTools::AL::SignalHandler;
+
+static const SignalHandler::signal_type WAITER_SIGNAL
+  = SignalHandler::SIGNAL_USER_1;
 
-#if WORKING || 1
 namespace
 {
-  void
-  wakeup( int SignalNumber )
+  static class Wakeup_
+    : public SignalHandler::Callback
   {
-    signal( SignalNumber, wakeup );
-  }
+  public:
+    typedef SignalHandler::signal_type signal_type;
+
+    virtual void
+    SignalCallback( signal_type Signal )
+    {
+    }
+  } wakeup;
 
   inline void
   debug_lock_acquire( const char* Proc, const char* LockName,
@@ -106,10 +115,10 @@ namespace LDASTools
     {
     public:
       struct timer_info {
-	key_t		s_key;
-	GPSTime		s_when;
-	int		s_signal;
-	pthread_t	s_thread;
+	key_t				s_key;
+	GPSTime				s_when;
+	SignalHandler::signal_type	s_signal;
+	pthread_t			s_thread;
       };
 
       typedef std::list< timer_info >	timers_type;
@@ -158,7 +167,7 @@ namespace LDASTools
 		 __FILE__, __LINE__,
 		 "Initializing TimerThead class" );
 #if USE_NANOSLEEP
-      signal( WAITER_SIGNAL, wakeup );
+      SignalHandler::Register( &wakeup, WAITER_SIGNAL );
 #elif USE_ALARM
       // Setup to be watching for SIGALRM signal
       sigset_t	sigs_to_block;
@@ -193,7 +202,8 @@ namespace LDASTools
       // Wakeup thread if it is sleeping
       //-------------------------------------------------------------------
       pthread_mutex_lock( &(p_->m_waiter_busy_lock) );
-      pthread_kill( p_->m_waiter_thread, WAITER_SIGNAL );
+      pthread_kill( p_->m_waiter_thread,
+		    SignalHandler::OSSignal( WAITER_SIGNAL ) );
       pthread_mutex_unlock( &(p_->m_waiter_busy_lock) );
       //-------------------------------------------------------------------
       // Wait for the thread to complete
@@ -204,7 +214,7 @@ namespace LDASTools
     /// Add a timer to the list of timers.
     /// The list is maintained in assending order.
     TimerThread::key_t TimerThread::
-    AddTimer( int Wakeup, int Signal )
+    AddTimer( int Wakeup, SignalHandler::signal_type Signal )
     {
       StdErrLog( ErrorLog::DEBUG,
 		 __FILE__, __LINE__,
@@ -369,7 +379,8 @@ namespace LDASTools
 	  //---------------------------------------------------------------
 	  // This is the case where an expired timer is in the queue.
 	  //---------------------------------------------------------------
-	  pthread_kill( pthread_self( ), SIGALRM );
+	  pthread_kill( pthread_self( ),
+			SignalHandler::OSSignal( SignalHandler::SIGNAL_ALARM ) );
 	}
 #endif
       }
@@ -437,7 +448,8 @@ namespace LDASTools
 	pthread_mutex_lock( &(m_waiter_busy_lock) );
 	debug_lock_acquire( "reset_timer", "m_waiter_busy_lock",
 			    __FILE__, __LINE__ );
-	pthread_kill( m_waiter_thread, WAITER_SIGNAL );
+	pthread_kill( m_waiter_thread,
+		      SignalHandler::OSSignal( WAITER_SIGNAL ) );
 	debug_lock_release_request( "reset_timer", "m_waiter_busy_lock",
 				    __FILE__, __LINE__ );
 	pthread_mutex_unlock( &(m_waiter_busy_lock) );
@@ -732,7 +744,8 @@ namespace LDASTools
 	    //-------------------------------------------------------------
 	    // Signal the requesting thread
 	    //-------------------------------------------------------------
-	    pthread_kill( info.s_thread, info.s_signal );
+	    pthread_kill( info.s_thread,
+			  SignalHandler::OSSignal( info.s_signal ) );
 	  }
 	  catch( ... )
 	  {
@@ -775,6 +788,4 @@ namespace LDASTools
   } // namespace - AL
 } // namespace - LDASTools
 
-#endif /* WORKING */
-
 SINGLETON_INSTANCE_DEFINITION(SingletonHolder<LDASTools::AL::TimerThread>)
