@@ -18,6 +18,10 @@ LDASTools::Testing::UnitTest Test;
 
 using LDASTools::AL::Task;
 using LDASTools::AL::FileType;
+using LDASTools::AL::SignalHandler;
+using LDASTools::AL::Thread;
+
+typedef SignalHandler::signal_type signal_type;
 
 namespace {
 #if 0
@@ -25,14 +29,15 @@ namespace {
     = "/archive/frames/E7/L0/LHO/H-R-6935/H-R-693591696-16.gwf";
 #endif /* 0 */
 
-  int init_interupt( );
+  signal_type init_interupt( );
 
   class timed_filetype
     : public Task
   {
   public:
     timed_filetype( const std::string& File )
-      : Task( init_interupt( ) ),
+      : Task( Thread::CANCEL_BY_SIGNAL,
+	      init_interupt( ) ),
 	m_file( File ),
 	m_file_type( "" )
     {
@@ -55,18 +60,22 @@ namespace {
     std::string		m_file_type;
   };
 
-  void
-  wakeup( int SignalNumber )
+  static class Wakeup_
+    : public SignalHandler::Callback
   {
-    signal( SignalNumber, wakeup );
-  }
+  public:
+    virtual void
+    SignalCallback( signal_type Signal )
+    {
+    }
+  } wakeup;
 
-  int
+  signal_type
   init_interupt( )
   {
-    static const int interupt = SIGTERM;
+    static const signal_type interupt = SignalHandler::SIGNAL_TERMINATE;
 
-    signal( interupt, wakeup );
+    SignalHandler::Register( &wakeup, interupt );
     return interupt;
   }
   
